/*
* File Name : gruntFile.js
* Purpose : grunt configuration for infopen-errors module
* Creation Date : 2014/05/2014
* Last Modified :
* Created By : Alexandre Chaussier, infOpen <a.chaussier@infopen.pro>
* License : GPLv3

This module is used to manage custom errors on infOpen programs.
Copyright (c) 2014 "Alexandre Chaussier, infOpen"
infOpen - IT company for small and medium companies [http://infopen.pro]

This file is part of infopen-errors.

infopen-errors is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>, or
write to the Free Software Foundation, Inc., 51 Franklin Street,
Fifth Floor, Boston, MA 02110-1301  USA.
*/

/**
 * @name gruntfile.js
 * @desc This file is the grunt main config file
 * @version 0.0.1
 */

'use strict';

module.exports = function(grunt) {

  // Create a banner which display some additionnal info with result
  var banner = '/*\n<%= pkg.name %> <%= pkg.version %>';
  banner += '- <%= pkg.description %>\n<%= pkg.repository.url %>\n';
  banner += 'Built on <%= grunt.template.today("yyyy-mm-dd") %>\n*/\n';

  // Load grunt tasks
  require('load-grunt-tasks')(grunt);

  // measures the time each task takes
  require('time-grunt')(grunt);

  // The configuration for grunt tasks is dynamically loaded
  var options = {
    config : {
      src : ['tasks/*.js']
    }
  };
  var configs = require('load-grunt-configs')(grunt, options);
  grunt.initConfig(configs);

  // Event handler for coverage by mocha_istanbul task
  grunt.event.on('coverage', function(lcovFileContents, done){
    console.log(lcovFileContents.slice(0, 15) + '...');
    done();
  });

  // Task registration
  grunt.registerTask('default', []);

};
