/*
* File Name : lib/ElementNotFoundError.js
* Purpose : This file contains the ElementNotFoundError declaration
* Creation Date : 2014/07/31
* Last Modified : mar. 01 juillet 2014 00:15:36 CEST
* Created By : Alexandre Chaussier, infOpen <a.chaussier@infopen.pro>
* License : GPLv3

This module is used to manage custom errors on infOpen programs.
Copyright (c) 2014 "Alexandre Chaussier, infOpen"
infOpen - IT company for small and medium companies [http://infopen.pro]

This file is part of infopen-errors.

infopen-errors is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>, or
write to the Free Software Foundation, Inc., 51 Franklin Street,
Fifth Floor, Boston, MA 02110-1301  USA.
*/

'use strict';

// Import dependencies
var inherits = require('util').inherits;
var inspect = require('util').inspect;
var InfopenError = require('../InfopenError');

var ElementNotFoundError = function ElementNotFoundError(element,
                                   containerName, dataType, moreInfos) {

  /*
   * Private variables
   */

  /** Object used to indexed function to execute depending error category */
  var _msg = 'Element not found (' + inspect(element) + ') used in the ';
  _msg += dataType + ' structure named : ' + inspect(containerName);


  /**
   * @constructor ElementNotFoundError
   * @desc This function define the ElementNotFoundError object
   * @inherits InfopenError
   * @param {*} element - element which caused the error
   * @param {string} containerName - container name if it's into a dataStructure
   * @param {string} dataType - DataType of object which throw the error
   * @param {*} moreInfos - Additionnal informations for this error
   * @return {ElementNotFoundError} Return a new instance of error
   */

  InfopenError.call(this, _msg);
  Error.captureStackTrace(this, ElementNotFoundError);

  this.element  = element;
  this.message   = _msg;
  this.containerName = containerName;
  this.datatype = dataType;
  this.severity  = 'critical';
  this.name      = 'ElementNotFoundError';

  if (moreInfos !== undefined) {
    this.moreInfos = moreInfos;
  }

  return this;
};
inherits(ElementNotFoundError, InfopenError);

module.exports = ElementNotFoundError;
