/*
* File Name : lib/InvalidCursorPositionError.js
* Purpose : This file contains the InvalidCursorPositionError declaration
* Creation Date : 2014/06/28
* Last Modified : sam. 28 juin 2014 20:46:36 CEST
* Created By : Alexandre Chaussier, infOpen <a.chaussier@infopen.pro>
* License : GPLv3

This module is used to manage custom errors on infOpen programs.
Copyright (c) 2014 "Alexandre Chaussier, infOpen"
infOpen - IT company for small and medium companies [http://infopen.pro]

This file is part of infopen-errors.

infopen-errors is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>, or
write to the Free Software Foundation, Inc., 51 Franklin Street,
Fifth Floor, Boston, MA 02110-1301  USA.
*/

'use strict';

// Import dependencies
var inherits = require('util').inherits;
var inspect = require('util').inspect;
var InfopenError = require('../InfopenError');

var InvalidCursorPositionError = function InvalidCursorPositionError(position,
                                   dataStoreLength, dataType, moreInfos) {

  /*
   * Private variables
   */

  /** Object used to indexed function to execute depending error category */
  var _msg = 'Invalid cursor position (' + inspect(position) + ') used in a ';
  _msg += dataType + ' with a dataStore of ' + inspect(dataStoreLength);
  _msg += ' elements !';


  /**
   * @constructor InvalidCursorPositionError
   * @desc This function define the InvalidCursorPositionError object
   * @inherits InfopenError
   * @param {integer} position - Position which caused error
   * @param {integer} dataStoreLength - Length of the dataStore
   * @param {string} dataType - DataType of object which throw the error
   * @param {*} moreInfos - Additionnal informations for this error
   * @return {InvalidCursorPositionError} Return a new instance of error
   */

  InfopenError.call(this, _msg);
  Error.captureStackTrace(this, InvalidCursorPositionError);

  this.position  = position;
  this.message   = _msg;
  this.dataStoreLength = dataStoreLength;
  this.datatype = dataType;
  this.severity  = 'critical';
  this.name      = 'InvalidCursorPositionError';

  if (moreInfos !== undefined) {
    this.moreInfos = moreInfos;
  }

  return this;
};
inherits(InvalidCursorPositionError, InfopenError);

module.exports = InvalidCursorPositionError;
