/*
* File Name : tests/ElementNotFoundError.js
* Purpose : The tests for the ElementNotFoundError class
* Creation Date : 2014/07/01
* Last Modified : mar. 01 juil 2014 00:26:58 CEST
* Created By : Alexandre Chaussier, infOpen <a.chaussier@infopen.pro>
* License : GPLv3

This module is used to manage custom errors on infOpen programs.
Copyright (c) 2014 "Alexandre Chaussier, infOpen"
infOpen - IT company for small and medium companies [http://infopen.pro]

This file is part of infopen-errors.

infopen-errors is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>, or
write to the Free Software Foundation, Inc., 51 Franklin Street,
Fifth Floor, Boston, MA 02110-1301  USA.
*/

/**
 * Test file for the ElementNotFoundError object in
 * lib/ElementNotFoundError.js
 * @version 0.0.1
 */

'use strict';

/**
 * @desc We overwrite the NODE_ENV variable
 */
process.env.NODE_ENV = 'test';

var expect = require('chai').expect;
var InfopenError = require('../InfopenError');
var ElementNotFoundError = require('../lib/ElementNotFoundError');

describe('infopen-errors', function() {

  describe('|- ElementNotFoundError', function() {

    var itMsg = 'Generate a ElementNotFoundError for list datatype';
    itMsg += ' without more infos';
    it(itMsg, function() {
      var errorMsg = 'Element not found ({ foo: \'bar\' }) used in ';
      errorMsg += 'the List structure named : \'foobar\'';
      var test = new ElementNotFoundError({foo: 'bar'}, 'foobar', 'List');

      expect(test).to.be.an.instanceof(InfopenError);
      expect(test).to.be.an.instanceof(ElementNotFoundError);
      expect(test).to.contain.keys(['name', 'element', 'message',
                                    'containerName', 'datatype', 'severity']);
      expect(test.name).to.be.equal('ElementNotFoundError');
      expect(test.element).to.contain.keys(['foo']);
      expect(test.element.foo).to.be.equal('bar');
      expect(test.containerName).to.be.equal('foobar');
      expect(test.datatype).to.be.equal('List');
      expect(test.severity).to.be.equal('critical');
      expect(test.moreInfos).to.be.a('undefined');
      expect(test.message).to.be.equal(errorMsg);
    });
    itMsg = 'Generate a ElementNotFoundError for list datatype';
    itMsg += ' with more infos';
    it(itMsg, function() {
      var errorMsg = 'Element not found ({ foo: \'bar\' }) used in ';
      errorMsg += 'the List structure named : \'foobar\'';
      var test = new ElementNotFoundError({foo: 'bar'}, 'foobar', 'List',
                                          {more: 'infos'});

      expect(test).to.be.an.instanceof(InfopenError);
      expect(test).to.be.an.instanceof(ElementNotFoundError);
      expect(test).to.contain.keys(['name', 'element', 'message',
                                    'containerName', 'datatype',
                                    'severity', 'moreInfos']);
      expect(test.name).to.be.equal('ElementNotFoundError');
      expect(test.element).to.contain.keys(['foo']);
      expect(test.element.foo).to.be.equal('bar');
      expect(test.containerName).to.be.equal('foobar');
      expect(test.datatype).to.be.equal('List');
      expect(test.severity).to.be.equal('critical');
      expect(test.moreInfos).to.contain.keys(['more']);
      expect(test.message).to.be.equal(errorMsg);
    });
  });
});
