/*
* File Name : tests/InvalidCursorPositionError.js
* Purpose : The tests for the InvalidCursorPositionError class
* Creation Date : 2014/06/28
* Last Modified : sam. 28 juin 2014 21:46:58 CEST
* Created By : Alexandre Chaussier, infOpen <a.chaussier@infopen.pro>
* License : GPLv3

This module is used to manage custom errors on infOpen programs.
Copyright (c) 2014 "Alexandre Chaussier, infOpen"
infOpen - IT company for small and medium companies [http://infopen.pro]

This file is part of infopen-errors.

infopen-errors is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>, or
write to the Free Software Foundation, Inc., 51 Franklin Street,
Fifth Floor, Boston, MA 02110-1301  USA.
*/

/**
 * Test file for the InvalidCursorPositionError object in
 * lib/InvalidCursorPositionError.js
 * @version 0.0.1
 */

'use strict';

/**
 * @desc We overwrite the NODE_ENV variable
 */
process.env.NODE_ENV = 'test';

var expect = require('chai').expect;
var InfopenError = require('../InfopenError');
var InvalidCursorPositionError = require('../lib/InvalidCursorPositionError');

describe('infopen-errors', function() {

  describe('|- InvalidCursorPositionError', function() {

    var itMsg = 'Generate a InvalidCursorPositionError for list datatype';
    itMsg += ' without more infos';
    it(itMsg, function() {
      var errorMsg = 'Invalid cursor position (12) used in a List with a ';
      errorMsg += 'dataStore of 10 elements !';
      var test = new InvalidCursorPositionError(12, 10, 'List');

      expect(test).to.be.an.instanceof(InfopenError);
      expect(test).to.be.an.instanceof(InvalidCursorPositionError);
      expect(test).to.contain.keys(['name', 'position', 'message',
                                    'dataStoreLength', 'datatype', 'severity']);
      expect(test.name).to.be.equal('InvalidCursorPositionError');
      expect(test.position).to.be.equal(12);
      expect(test.dataStoreLength).to.be.equal(10);
      expect(test.datatype).to.be.equal('List');
      expect(test.severity).to.be.equal('critical');
      expect(test.moreInfos).to.be.a('undefined');
      expect(test.message).to.be.equal(errorMsg);
    });
    itMsg = 'Generate a InvalidCursorPositionError for list datatype';
    itMsg += ' with more infos';
    it(itMsg, function() {
      var errorMsg = 'Invalid cursor position (12) used in a List with a ';
      errorMsg += 'dataStore of 10 elements !';
      var test = new InvalidCursorPositionError(12, 10, 'List', { foo: 'bar' });

      expect(test).to.be.an.instanceof(InfopenError);
      expect(test).to.be.an.instanceof(InvalidCursorPositionError);
      expect(test).to.contain.keys(['name', 'position', 'message',
                                    'dataStoreLength', 'datatype',
                                    'severity', 'moreInfos']);
      expect(test.name).to.be.equal('InvalidCursorPositionError');
      expect(test.position).to.be.equal(12);
      expect(test.dataStoreLength).to.be.equal(10);
      expect(test.datatype).to.be.equal('List');
      expect(test.severity).to.be.equal('critical');
      expect(test.moreInfos).to.contain.keys(['foo']);
      expect(test.message).to.be.equal(errorMsg);
    });
  });
});
