/*
* File Name : tests/ParameterError.js
* Purpose : The tests for the ParameterError class
* Creation Date : 2014/05/24
* Last Modified : sam. 24 mai 2014 22:46:58 CEST
* Created By : Alexandre Chaussier, infOpen <a.chaussier@infopen.pro>
* License : GPLv3

This module is used to manage custom errors on infOpen programs.
Copyright (c) 2014 "Alexandre Chaussier, infOpen"
infOpen - IT company for small and medium companies [http://infopen.pro]

This file is part of infopen-errors.

infopen-errors is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>, or
write to the Free Software Foundation, Inc., 51 Franklin Street,
Fifth Floor, Boston, MA 02110-1301  USA.
*/

/**
 * @desc Test file for the ParameterError object in lib/ParameterError.js
 * @version 0.0.1
 */

'use strict';

/**
 * @desc We overwrite the NODE_ENV variable
 */
process.env.NODE_ENV = 'test';

var expect = require('chai').expect;
var InfopenError = require('../InfopenError');
var ParameterError = require('../lib/ParameterError');

describe('infopen-errors', function() {

  describe('|- ParameterError', function() {

    it('Generate a ParameterError for badType category', function() {
      var errorMsg = 'Bad type for "foo" parameter in "foobar()".';
      errorMsg += ' Expected : "string" but received "bar"';

      var test = new ParameterError('foo', 'badType', null, 'foobar()', 'bar',
                       'string', {test: 'foo'});

      expect(test).to.be.an.instanceof(InfopenError);
      expect(test).to.be.an.instanceof(ParameterError);
      expect(test).to.contain.keys(['name', 'category', 'message', 'parameter',
                                    'source', 'severity', 'moreInfos']);
      expect(test.name).to.be.equal('ParameterError');
      expect(test.category).to.be.equal('badType');
      expect(test.parameter).to.be.equal('foo');
      expect(test.source).to.be.equal('foobar()');
      expect(test.severity).to.be.a('null');
      expect(test.moreInfos).to.contain.keys(['test']);
      expect(test.message).to.be.equal(errorMsg);
    });
    it('Generate a ParameterError for badValue category', function() {
      var errorMsg = 'Bad value for "foo" parameter in "foobar()". ';
      errorMsg += 'Expected : "string" but received "bar"';

      var test = new ParameterError('foo', 'badValue', null, 'foobar()', 'bar',
                       'string', null);
      expect(test).to.be.an.instanceof(InfopenError);
      expect(test).to.be.an.instanceof(ParameterError);
      expect(test).to.contain.keys(['name', 'category', 'message', 'parameter',
                                    'source', 'severity', 'moreInfos']);
      expect(test.name).to.be.equal('ParameterError');
      expect(test.category).to.be.equal('badValue');
      expect(test.parameter).to.be.equal('foo');
      expect(test.source).to.be.equal('foobar()');
      expect(test.severity).to.be.a('null');
      expect(test.moreInfos).to.be.a('null');
      expect(test.message).to.be.equal(errorMsg);
    });
    it('Generate a ParameterError for mandatoryNotSent category', function() {
      var errorMsg = '"foo" parameter in "foobar()" is mandatory !';

      var test = new ParameterError('foo', 'mandatoryNotSent', null, 'foobar()',
                       'bar', 'string', null);
      expect(test).to.be.an.instanceof(InfopenError);
      expect(test).to.be.an.instanceof(ParameterError);
      expect(test).to.contain.keys(['name', 'category', 'message', 'parameter',
                                    'source', 'severity', 'moreInfos']);
      expect(test.name).to.be.equal('ParameterError');
      expect(test.category).to.be.equal('mandatoryNotSent');
      expect(test.parameter).to.be.equal('foo');
      expect(test.source).to.be.equal('foobar()');
      expect(test.severity).to.be.a('null');
      expect(test.moreInfos).to.be.a('null');
      expect(test.message).to.be.equal(errorMsg);
    });
    it('Generate a ParameterError for an unknown category', function() {
      var errorMsg = 'Unknown parameter error on "foobar()" ';
      errorMsg += 'for parameter "foo" with value "bar"';

      var test = new ParameterError('foo', 'foobar', null, 'foobar()', 'bar',
                       'string');
      expect(test).to.be.an.instanceof(InfopenError);
      expect(test).to.be.an.instanceof(ParameterError);
      expect(test).to.contain.keys(['name', 'category', 'message', 'parameter',
                                    'source', 'severity']);
      expect(test.name).to.be.equal('ParameterError');
      expect(test.category).to.be.equal('foobar');
      expect(test.parameter).to.be.equal('foo');
      expect(test.source).to.be.equal('foobar()');
      expect(test.severity).to.be.a('null');
      expect(test.moreInfos).to.be.a('undefined');
      expect(test.message).to.be.equal(errorMsg);
    });
  });
});
